class LedError(Exception):
    """
    Raised when there is an error while working with the LED class.
    """
    def __init__(self):
        pass

class RGBLedError(Exception):
    """
    Raised when there is an error while working with the RGB_LED class.
    """
    def __init__(self):
        pass
